@@ -688,9 +688,7 @@ def Angular_residues_np(test_Matrix, twicetheta_data, chi_data, ang_tol=0.5,
     # of spots exiting the crystal towards detector plane and geometry given by kf_direction
     spots2pi = LAUE.getLaueSpots(CST_ENERGYKEV / emax, CST_ENERGYKEV / emin,
                                     [grain],
-                                    1,
                                     fastcompute=1,
-                                    fileOK=0,
                                     verbose=0,
                                     kf_direction=kf_direction,
                                     ResolutionAngstrom=ResolutionAngstrom,
@@ -797,9 +795,7 @@ def Angular_residues_np_multimatrices(ListMatrices, twicetheta_data, chi_data, a
         spots2pi = LAUE.getLaueSpots(CST_ENERGYKEV / emax,
                                     CST_ENERGYKEV / emin,
                                     [grain],
-                                    1,
                                     fastcompute=1,
-                                    fileOK=0,
                                     verbose=0,
                                     kf_direction=kf_direction,
                                     ResolutionAngstrom=ResolutionAngstrom,
@@ -867,9 +863,7 @@ def Angular_residues(test_Matrix, twicetheta_data, chi_data, ang_tol=0.5, key_ma
     spots2pi = LAUE.getLaueSpots(CST_ENERGYKEV / emax,
                                     CST_ENERGYKEV / emin,
                                     [grain],
-                                    1,
                                     fastcompute=1,
-                                    fileOK=0,
                                     verbose=0,
                                     kf_direction=kf_direction,
                                     ResolutionAngstrom=ResolutionAngstrom,
